pub struct VisRegionData {
pub self_key: Option<Uoid>,
pub region_key: Option<Uoid>,
pub disable_normal: bool,
pub is_not: bool,
pub replace_normal: bool,
pub disabled: bool,
}Expand description
A visibility region — groups objects by visibility. C++ ref: plVisRegion.h — properties kDisable=0, kIsNot=1, kReplaceNormal=2, kDisableNormal=3
Fields
self_key: Option<Uoid>region_key: Option<Uoid>Key to the soft volume region (plRegionBase / plSoftVolume).
disable_normal: boolIf true, this region disables normal rendering when active.
is_not: boolIf true, this is a “not” region — excludes objects from rendering.
replace_normal: boolIf true, replaces normal visibility (default: true).
disabled: boolIf true, region is disabled and always returns false.